/**
 * Copyright (c) 2008-2012 EBMWebsourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.jbidescriptor;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import java.io.InputStreamReader;
import java.net.URL;

import javax.xml.parsers.DocumentBuilderFactory;

import org.junit.Test;
import org.ow2.petals.component.framework.jbidescriptor.generated.Jbi;
import org.w3c.dom.Document;

/**
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class JBIDescriptorBuilderTest {

    /**
     * @throws Exception
     */
    @Test
    public void testComponentDescValidating() throws Exception {
        URL xmlURL = this.getClass().getResource("/component.xml");
        try {
            JBIDescriptorBuilder.validateJBIDescriptor(xmlURL.openStream());
        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    @Test
    public void testComponentDescJavaBuilding_000() throws Exception {
        URL xmlURL = this.getClass().getResource("/component.xml");
        try {
            JBIDescriptorBuilder.buildJavaJBIDescriptor(xmlURL.openStream());
        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    @Test
    public void testComponentDescJavaBuilding_001() throws Exception {
        URL xmlURL = this.getClass().getResource("/component.xml");
        try {
            JBIDescriptorBuilder.buildJavaJBIDescriptor(new InputStreamReader(xmlURL.openStream()));
        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    
    /**
     * 
     * @throws Exception
     */
    @Test
    public void testComponentDescXMLBuilding() throws Exception {
        URL xmlURL = this.getClass().getResource("/component.xml");

        try {
            Jbi jbi = JBIDescriptorBuilder.buildJavaJBIDescriptor(xmlURL.openStream());
            Document document = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
            JBIDescriptorBuilder.buildXmlJBIdescriptor(jbi, document);

            assertEquals(document.getFirstChild().getFirstChild().getLocalName(), "component");

        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    /**
     * 
     * @throws Exception
     */
    @Test
    public void testSUProvideDescValidating() throws Exception {
        URL xmlURL = this.getClass().getResource("/su-provide.xml");
        try {
            JBIDescriptorBuilder.validateJBIDescriptor(xmlURL.openStream());
        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    /**
     * 
     * @throws Exception
     */
    public void testSUProvideDescJavaBuilding() throws Exception {
        URL xmlURL = this.getClass().getResource("/su-provide.xml");

        try {
            JBIDescriptorBuilder.buildJavaJBIDescriptor(xmlURL.openStream());
        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    /**
     * 
     * @throws Exception
     */
    @Test
    public void testSUProvideDescXmlBuilding() throws Exception {
        URL xmlURL = this.getClass().getResource("/su-provide.xml");

        try {
            Jbi jbi = JBIDescriptorBuilder.buildJavaJBIDescriptor(xmlURL.openStream());
            Document document = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
            JBIDescriptorBuilder.buildXmlJBIdescriptor(jbi, document);

            assertEquals(document.getFirstChild().getFirstChild().getFirstChild().getLocalName(),
                    "provides");

        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    /**
     * 
     * @throws Exception
     */
    @Test
    public void testSUConsumeDescValidating() throws Exception {
        URL xmlURL = this.getClass().getResource("/su-consume.xml");

        try {
            JBIDescriptorBuilder.validateJBIDescriptor(xmlURL.openStream());
        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    /**
     * @throws Exception
     */
    @Test
    public void testSUConsumeDescJavaBuilding() throws Exception {
        URL xmlURL = this.getClass().getResource("/su-consume.xml");

        try {
            JBIDescriptorBuilder.buildJavaJBIDescriptor(xmlURL.openStream());
        } catch (Exception e) {
            fail(e.getMessage());
        }
    }

    /**
     * @throws Exception
     */
    @Test
    public void testSUConsumeDescXmlBuilding() throws Exception {
        URL xmlURL = this.getClass().getResource("/su-consume.xml");

        try {
            Jbi jbi = JBIDescriptorBuilder.buildJavaJBIDescriptor(xmlURL.openStream());
            Document document = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
            JBIDescriptorBuilder.buildXmlJBIdescriptor(jbi, document);

            assertEquals(document.getFirstChild().getFirstChild().getFirstChild().getLocalName(),
                    "consumes");

        } catch (Exception e) {
            fail(e.getMessage());
        }
    }
}
